@@ -105,11 +105,11 @@ class ListProperty(PropertyProtocol):
     def convert_value(self, value: Any) -> Value | None | PropertyError:
         return None  # pragma: no cover
 
-    def get_base_type_string(self, *, quoted: bool = False) -> str:
-        return f"list[{self.inner_property.get_type_string(quoted=not self.inner_property.is_base_type)}]"
+    def get_base_type_string(self) -> str:
+        return f"list[{self.inner_property.get_type_string()}]"
 
-    def get_base_json_type_string(self, *, quoted: bool = False) -> str:
-        return f"list[{self.inner_property.get_type_string(json=True, quoted=not self.inner_property.is_base_type)}]"
+    def get_base_json_type_string(self) -> str:
+        return f"list[{self.inner_property.get_type_string(json=True)}]"
 
     def get_instance_type_string(self) -> str:
         """Get a string representation of runtime type that should be used for `isinstance` checks"""
@@ -137,8 +137,6 @@ class ListProperty(PropertyProtocol):
         self,
         no_optional: bool = False,
         json: bool = False,
-        *,
-        quoted: bool = False,
     ) -> str:
         """
         Get a string representation of type that should be used when declaring this property
@@ -154,4 +152,4 @@ class ListProperty(PropertyProtocol):
 
         if no_optional or self.required:
             return type_string
-        return f"Union[Unset, {type_string}]"
+        return f"{type_string} | Unset"
