@@ -140,8 +140,8 @@ class ModelProperty(PropertyProtocol):
         """Constructs a self import statement from this ModelProperty's attributes"""
         return f"models.{self.class_info.module_name} import {self.class_info.name}"
 
-    def get_base_type_string(self, *, quoted: bool = False) -> str:
-        return f'"{self.class_info.name}"' if quoted else self.class_info.name
+    def get_base_type_string(self) -> str:
+        return self.class_info.name
 
     def get_imports(self, *, prefix: str) -> set[str]:
         """
@@ -188,9 +188,6 @@ class ModelProperty(PropertyProtocol):
         self,
         no_optional: bool = False,
         json: bool = False,
-        *,
-        multipart: bool = False,
-        quoted: bool = False,
     ) -> str:
         """
         Get a string representation of type that should be used when declaring this property
@@ -201,18 +198,12 @@ class ModelProperty(PropertyProtocol):
         """
         if json:
             type_string = self.get_base_json_type_string()
-        elif multipart:
-            type_string = "tuple[None, bytes, str]"
         else:
             type_string = self.get_base_type_string()
 
-        if quoted:
-            if type_string == self.class_info.name:
-                type_string = f"'{type_string}'"
-
         if no_optional or self.required:
             return type_string
-        return f"Union[Unset, {type_string}]"
+        return f"{type_string} | Unset"
 
 
 from .property import Property  # noqa: E402
@@ -245,8 +236,8 @@ def _process_properties(  # noqa: PLR0912, PLR0911
     config: Config,
     roots: set[ReferencePath | utils.ClassName],
 ) -> _PropertyData | PropertyError:
-    from . import property_from_data
-    from .merge_properties import merge_properties
+    from . import property_from_data  # noqa: PLC0415
+    from .merge_properties import merge_properties  # noqa: PLC0415
 
     properties: dict[str, Property] = {}
     relative_imports: set[str] = set()
@@ -356,7 +347,7 @@ def _get_additional_properties(
     config: Config,
     roots: set[ReferencePath | utils.ClassName],
 ) -> tuple[Property | None | PropertyError, Schemas]:
-    from . import property_from_data
+    from . import property_from_data  # noqa: PLC0415
 
     if schema_additional is None:
         return ANY_ADDITIONAL_PROPERTY, schemas
