@@ -1,6 +1,4 @@
-from typing import Optional
-
-from pydantic import BaseModel, Extra
+from pydantic import BaseModel, ConfigDict
 
 from .contact import Contact
 from .license import License
@@ -18,15 +16,14 @@ class Info(BaseModel):
     """
 
     title: str
-    description: Optional[str] = None
-    termsOfService: Optional[str] = None
-    contact: Optional[Contact] = None
-    license: Optional[License] = None
+    description: str | None = None
+    termsOfService: str | None = None
+    contact: Contact | None = None
+    license: License | None = None
     version: str
-
-    class Config:  # pylint: disable=missing-class-docstring
-        extra = Extra.allow
-        schema_extra = {
+    model_config = ConfigDict(
+        extra="allow",
+        json_schema_extra={
             "examples": [
                 {
                     "title": "Sample Pet Store App",
@@ -41,4 +38,5 @@ class Info(BaseModel):
                     "version": "1.0.1",
                 }
             ]
-        }
+        },
+    )
